@@ -1,19 +1,32 @@
 import json
 import pathlib
 import sys
+import warnings
 from base64 import decodebytes, encodebytes
 from unicodedata import normalize
 
 import pytest
 import tornado
-from nbformat import from_dict, writes
+from nbformat import from_dict
 from nbformat.v4 import new_markdown_cell, new_notebook
 
 from jupyter_server.utils import url_path_join
+from tests.conftest import dirs
 
 from ...utils import expected_http_error
 
 
+@pytest.fixture(autouse=True)
+def suppress_deprecation_warnings():
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore",
+            message="The synchronous ContentsManager",
+            category=DeprecationWarning,
+        )
+        yield
+
+
 def notebooks_only(dir_model):
     return [nb for nb in dir_model["content"] if nb["type"] == "notebook"]
 
@@ -22,22 +35,6 @@ def dirs_only(dir_model):
     return [x for x in dir_model["content"] if x["type"] == "directory"]
 
 
-dirs = [
-    ("", "inroot"),
-    ("Directory with spaces in", "inspace"),
-    ("unicodé", "innonascii"),
-    ("foo", "a"),
-    ("foo", "b"),
-    ("foo", "name with spaces"),
-    ("foo", "unicodé"),
-    ("foo/bar", "baz"),
-    ("ordering", "A"),
-    ("ordering", "b"),
-    ("ordering", "C"),
-    ("å b", "ç d"),
-]
-
-
 @pytest.fixture(params=["FileContentsManager", "AsyncFileContentsManager"])
 def jp_argv(request):
     return [
@@ -46,49 +43,6 @@ def jp_argv(request):
     ]
 
 
-@pytest.fixture
-def contents_dir(tmp_path, jp_serverapp):
-    return tmp_path / jp_serverapp.root_dir
-
-
-@pytest.fixture
-def contents(contents_dir):
-    # Create files in temporary directory
-    paths: dict = {
-        "notebooks": [],
-        "textfiles": [],
-        "blobs": [],
-    }
-    for d, name in dirs:
-        p = contents_dir / d
-        p.mkdir(parents=True, exist_ok=True)
-
-        # Create a notebook
-        nb = writes(new_notebook(), version=4)
-        nbname = p.joinpath(f"{name}.ipynb")
-        nbname.write_text(nb, encoding="utf-8")
-        paths["notebooks"].append(nbname.relative_to(contents_dir))
-
-        # Create a text file
-        txt = f"{name} text file"
-        txtname = p.joinpath(f"{name}.txt")
-        txtname.write_text(txt, encoding="utf-8")
-        paths["textfiles"].append(txtname.relative_to(contents_dir))
-
-        # Create a random blob
-        blob = name.encode("utf-8") + b"\xFF"
-        blobname = p.joinpath(f"{name}.blob")
-        blobname.write_bytes(blob)
-        paths["blobs"].append(blobname.relative_to(contents_dir))
-    paths["all"] = list(paths.values())
-    return paths
-
-
-@pytest.fixture
-def folders():
-    return list({item[0] for item in dirs})
-
-
 @pytest.mark.parametrize("path,name", dirs)
 async def test_list_notebooks(jp_fetch, contents, path, name):
     response = await jp_fetch(
@@ -230,19 +184,20 @@ async def test_get_text_file_contents(jp_fetch, contents, path, name):
         )
     assert expected_http_error(e, 400)
 
+
 @pytest.mark.skipif(sys.platform == "win32", reason="Disabled retrieving hidden files on Windows")
 async def test_get_404_hidden(jp_fetch, contents, contents_dir):
     # Create text files
-    hidden_dir = contents_dir / '.hidden'
+    hidden_dir = contents_dir / ".hidden"
     hidden_dir.mkdir(parents=True, exist_ok=True)
-    txt = f"visible text file in hidden dir"
-    txtname = hidden_dir.joinpath(f"visible.txt")
+    txt = "visible text file in hidden dir"
+    txtname = hidden_dir.joinpath("visible.txt")
     txtname.write_text(txt, encoding="utf-8")
 
-    txt2 = f"hidden text file"
-    txtname2 = contents_dir.joinpath(f".hidden.txt")
+    txt2 = "hidden text file"
+    txtname2 = contents_dir.joinpath(".hidden.txt")
     txtname2.write_text(txt2, encoding="utf-8")
-   
+
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch(
             "api",
@@ -261,6 +216,7 @@ async def test_get_404_hidden(jp_fetch, contents, contents_dir):
         )
     assert expected_http_error(e, 404)
 
+
 @pytest.mark.parametrize("path,name", dirs)
 async def test_get_binary_file_contents(jp_fetch, contents, path, name):
     blobname = name + ".blob"
@@ -347,6 +303,10 @@ async def test_create_untitled(jp_fetch, contents, contents_dir, _check_created)
     r = await jp_fetch("api", "contents", path, method="POST", body=json.dumps({"ext": ".ipynb"}))
     _check_created(r, str(contents_dir), path, name, type="notebook")
 
+    name = "untitled"
+    r = await jp_fetch("api", "contents", path, method="POST", allow_nonstandard_methods=True)
+    _check_created(r, str(contents_dir), path, name=name, type="file")
+
 
 async def test_create_untitled_txt(jp_fetch, contents, contents_dir, _check_created):
     name = "untitled.txt"
@@ -441,48 +401,38 @@ async def test_upload_txt(jp_fetch, contents, contents_dir, _check_created):
 @pytest.mark.skipif(sys.platform == "win32", reason="Disabled uploading hidden files on Windows")
 async def test_upload_txt_hidden(jp_fetch, contents, contents_dir):
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        body = 'ünicode téxt'
+        body = "ünicode téxt"
         model = {
-            'content' : body,
-            'format'  : 'text',
-            'type'    : 'file',
+            "content": body,
+            "format": "text",
+            "type": "file",
         }
-        path = '.hidden/Upload tést.txt'
+        path = ".hidden/Upload tést.txt"
         await jp_fetch("api", "contents", path, method="PUT", body=json.dumps(model))
     assert expected_http_error(e, 400)
 
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        body = 'ünicode téxt'
-        model = {
-            'content' : body,
-            'format'  : 'text',
-            'type'    : 'file',
-            'path': '.hidden/test.txt'
-        }
-        path = 'Upload tést.txt'
+        body = "ünicode téxt"
+        model = {"content": body, "format": "text", "type": "file", "path": ".hidden/test.txt"}
+        path = "Upload tést.txt"
         await jp_fetch("api", "contents", path, method="PUT", body=json.dumps(model))
     assert expected_http_error(e, 400)
 
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        body = 'ünicode téxt'
+        body = "ünicode téxt"
         model = {
-            'content' : body,
-            'format'  : 'text',
-            'type'    : 'file',
+            "content": body,
+            "format": "text",
+            "type": "file",
         }
-        path = '.hidden.txt'
+        path = ".hidden.txt"
         await jp_fetch("api", "contents", path, method="PUT", body=json.dumps(model))
     assert expected_http_error(e, 400)
 
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        body = 'ünicode téxt'
-        model = {
-            'content' : body,
-            'format'  : 'text',
-            'type'    : 'file',
-            'path': '.hidden.txt'
-        }
-        path = 'Upload tést.txt'
+        body = "ünicode téxt"
+        model = {"content": body, "format": "text", "type": "file", "path": ".hidden.txt"}
+        path = "Upload tést.txt"
         await jp_fetch("api", "contents", path, method="PUT", body=json.dumps(model))
     assert expected_http_error(e, 400)
 
@@ -581,7 +531,11 @@ async def test_copy_put_400(jp_fetch, contents, contents_dir, _check_created):
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Disabled copying hidden files on Windows")
-async def test_copy_put_400_hidden(jp_fetch, contents, contents_dir,):
+async def test_copy_put_400_hidden(
+    jp_fetch,
+    contents,
+    contents_dir,
+):
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch(
             "api",
@@ -591,7 +545,7 @@ async def test_copy_put_400_hidden(jp_fetch, contents, contents_dir,):
             body=json.dumps({"copy_from": "new.txt"}),
         )
     assert expected_http_error(e, 400)
-    
+
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch(
             "api",
@@ -601,7 +555,7 @@ async def test_copy_put_400_hidden(jp_fetch, contents, contents_dir,):
             body=json.dumps({"copy_from": ".hidden/new.txt"}),
         )
     assert expected_http_error(e, 400)
-    
+
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch(
             "api",
@@ -611,7 +565,7 @@ async def test_copy_put_400_hidden(jp_fetch, contents, contents_dir,):
             body=json.dumps({"copy_from": "new.txt"}),
         )
     assert expected_http_error(e, 400)
-    
+
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch(
             "api",
@@ -636,16 +590,20 @@ async def test_copy_dir_400(jp_fetch, contents, contents_dir, _check_created):
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Disabled copying hidden files on Windows")
-async def test_copy_400_hidden(jp_fetch, contents, contents_dir,):
+async def test_copy_400_hidden(
+    jp_fetch,
+    contents,
+    contents_dir,
+):
 
     # Create text files
-    hidden_dir = contents_dir / '.hidden'
+    hidden_dir = contents_dir / ".hidden"
     hidden_dir.mkdir(parents=True, exist_ok=True)
-    txt = f"visible text file in hidden dir"
-    txtname = hidden_dir.joinpath(f"new.txt")
+    txt = "visible text file in hidden dir"
+    txtname = hidden_dir.joinpath("new.txt")
     txtname.write_text(txt, encoding="utf-8")
 
-    paths = ['new.txt', '.hidden.txt']
+    paths = ["new.txt", ".hidden.txt"]
     for name in paths:
         txt = f"{name} text file"
         txtname = contents_dir.joinpath(f"{name}.txt")
@@ -660,7 +618,7 @@ async def test_copy_400_hidden(jp_fetch, contents, contents_dir,):
             body=json.dumps({"copy_from": "new.txt"}),
         )
     assert expected_http_error(e, 400)
-    
+
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch(
             "api",
@@ -689,7 +647,7 @@ async def test_copy_400_hidden(jp_fetch, contents, contents_dir,):
             method="POST",
             body=json.dumps({"copy_from": ".hidden.txt"}),
         )
-    assert expected_http_error(e, 400)    
+    assert expected_http_error(e, 400)
 
 
 @pytest.mark.parametrize("path,name", dirs)
@@ -707,7 +665,7 @@ async def test_delete(jp_fetch, contents, contents_dir, path, name, _check_creat
 
 async def test_delete_dirs(jp_fetch, contents, folders):
     # Iterate over folders
-    for name in sorted(folders + ["/"], key=len, reverse=True):
+    for name in sorted([*folders, "/"], key=len, reverse=True):
         r = await jp_fetch("api", "contents", name, method="GET")
         # Get JSON blobs for each content.
         listing = json.loads(r.body.decode())["content"]
@@ -729,20 +687,22 @@ async def test_delete_non_empty_dir(jp_fetch, contents):
         await jp_fetch("api", "contents", "å b", method="GET")
     assert expected_http_error(e, 404)
 
+
 @pytest.mark.skipif(sys.platform == "win32", reason="Disabled deleting hidden dirs on Windows")
 async def test_delete_hidden_dir(jp_fetch, contents):
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch("api", "contents", ".hidden", method="DELETE")
     assert expected_http_error(e, 400)
 
+
 @pytest.mark.skipif(sys.platform == "win32", reason="Disabled deleting hidden dirs on Windows")
 async def test_delete_hidden_file(jp_fetch, contents):
-    #Test deleting file in a hidden directory
+    # Test deleting file in a hidden directory
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch("api", "contents", ".hidden/test.txt", method="DELETE")
     assert expected_http_error(e, 400)
 
-    #Test deleting a hidden file
+    # Test deleting a hidden file
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
         await jp_fetch("api", "contents", ".hidden.txt", method="DELETE")
     assert expected_http_error(e, 400)
@@ -778,37 +738,12 @@ async def test_rename(jp_fetch, jp_base_url, contents, contents_dir):
     assert "z.ipynb" in nbnames
     assert "a.ipynb" not in nbnames
 
+
 @pytest.mark.skipif(sys.platform == "win32", reason="Disabled copying hidden files on Windows")
 async def test_rename_400_hidden(jp_fetch, jp_base_url, contents, contents_dir):
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        old_path = '.hidden/old.txt'
-        new_path = 'new.txt'
-        # Rename the file
-        r = await jp_fetch(
-            "api",
-            "contents",
-            old_path,
-            method="PATCH",
-            body=json.dumps({"path": new_path}),
-        )
-    assert expected_http_error(e, 400)
-        
-    with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        old_path = 'old.txt'
-        new_path = '.hidden/new.txt'
-        # Rename the file
-        r = await jp_fetch(
-            "api",
-            "contents",
-            old_path,
-            method="PATCH",
-            body=json.dumps({"path": new_path}),
-        )
-    assert expected_http_error(e, 400)
-        
-    with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        old_path = '.hidden.txt'
-        new_path = 'new.txt'
+        old_path = ".hidden/old.txt"
+        new_path = "new.txt"
         # Rename the file
         r = await jp_fetch(
             "api",
@@ -820,8 +755,34 @@ async def test_rename_400_hidden(jp_fetch, jp_base_url, contents, contents_dir):
     assert expected_http_error(e, 400)
 
     with pytest.raises(tornado.httpclient.HTTPClientError) as e:
-        old_path = 'old.txt'
-        new_path = '.hidden.txt'
+        old_path = "old.txt"
+        new_path = ".hidden/new.txt"
+        # Rename the file
+        r = await jp_fetch(
+            "api",
+            "contents",
+            old_path,
+            method="PATCH",
+            body=json.dumps({"path": new_path}),
+        )
+    assert expected_http_error(e, 400)
+
+    with pytest.raises(tornado.httpclient.HTTPClientError) as e:
+        old_path = ".hidden.txt"
+        new_path = "new.txt"
+        # Rename the file
+        r = await jp_fetch(
+            "api",
+            "contents",
+            old_path,
+            method="PATCH",
+            body=json.dumps({"path": new_path}),
+        )
+    assert expected_http_error(e, 400)
+
+    with pytest.raises(tornado.httpclient.HTTPClientError) as e:
+        old_path = "old.txt"
+        new_path = ".hidden.txt"
         # Rename the file
         r = await jp_fetch(
             "api",
@@ -834,6 +795,7 @@ async def test_rename_400_hidden(jp_fetch, jp_base_url, contents, contents_dir):
 
 
 async def test_checkpoints_follow_file(jp_fetch, contents):
+
     path = "foo"
     name = "a.ipynb"
 
